@@ -103,6 +103,7 @@ function ftp_chdir($connection, $directory)
         'file2.txt',
         'file3.txt',
         'file4.txt',
+        'file5WithPadding.txt',
         'dir1',
         'file1.with-total-line.txt',
         'file1.with-invalid-line.txt',
@@ -125,6 +126,10 @@ function ftp_raw($connection, $command)
     }
 
     if ($command === 'OPTS UTF8 ON') {
+        if ($connection === 'utf8.alreadyActive') {
+            return [0 => '202 UTF8 mode is always enabled. No need to send this command.'];
+        }
+
         return [0 => '200 UTF8 set to on'];
     }
 
@@ -225,6 +230,12 @@ function ftp_rawlist($connection, $directory)
         ];
     }
 
+    if (strpos($directory, 'file5WithPadding.txt') !== false) {
+        return [
+            '   2016-05-23  12:09PM                  685 file5WithPadding.txt',
+        ];
+    }
+
     if (strpos($directory, 'dir1') !== false) {
         return [
             '2015-05-23  12:09       <DIR>          dir1',
@@ -564,6 +575,14 @@ class FtpTests extends TestCase
         $this->assertEquals('public', $metadata['visibility']);
         $this->assertEquals(684, $metadata['size']);
 
+        $metadata = $adapter->getMetadata('file5WithPadding.txt');
+        $this->assertIsArray($metadata);
+        $this->assertEquals('file', $metadata['type']);
+        $this->assertEquals('file5WithPadding.txt', $metadata['path']);
+        $this->assertEquals(1464005340, $metadata['timestamp']);
+        $this->assertEquals('public', $metadata['visibility']);
+        $this->assertEquals(685, $metadata['size']);
+
         $metadata = $adapter->getMetadata('dir1');
         $this->assertEquals('dir', $metadata['type']);
         $this->assertEquals('dir1', $metadata['path']);
@@ -662,7 +681,7 @@ class FtpTests extends TestCase
                     [
                         'type' => 'dir',
                         'path' => 'folder',
-                        'timestamp' => 1606226340,
+                        'timestamp' => DateTime::createFromFormat('M d H:i', 'Nov 24 13:59')->getTimestamp(),
                     ],
                     [
                         'type' => 'file',
@@ -693,7 +712,7 @@ class FtpTests extends TestCase
                     [
                         'type' => 'dir',
                         'path' => 'folder',
-                        'timestamp' => 1606226340,
+                        'timestamp' => DateTime::createFromFormat('M d H:i', 'Nov 24 13:59')->getTimestamp(),
                     ],
                     [
                         'type' => 'file',
@@ -926,6 +945,16 @@ class FtpTests extends TestCase
         $this->assertNull($adapter->connect());
     }
 
+        /**
+     * @depends testInstantiable
+     */
+    public function testItSetUtf8ModeWhenAlreadySetByServer()
+    {
+        $adapter = new Ftp(['host' => 'utf8.alreadyActive', 'utf8' => true]);
+        $adapter->setUtf8(true);
+        $this->assertNull($adapter->connect());
+    }
+
     /**
      * @depends testInstantiable
      */
